@@ -220,10 +220,11 @@ iorder <- function(obj = NULL, var_name = NULL) {
     src_var <- reactive({
       if (is.data.frame(robj())) {
         ## Formatted source variable name
-        result <- ifelse(grepl(" ", req(input$var_name)),
-          sprintf('%s[,"%s"]', req(input$obj_name), req(input$var_name)),
-          sprintf("%s$%s", req(input$obj_name), req(input$var_name))
-        )
+        var_name <- req(input$var_name)
+        if (make.names(var_name) != var_name) {
+          var_name <- paste0('`', var_name, '`')
+        }
+        result <- sprintf("%s$%s", req(input$obj_name), var_name)        
       }
       if (is.vector(robj()) || is.factor(robj())) {
         result <- req(input$obj_name)
@@ -344,10 +345,11 @@ iorder <- function(obj = NULL, var_name = NULL) {
     ## Generate reordering code
     generate_code <- function(check = FALSE) {
       if (is.data.frame(robj())) {
-        dest_var <- ifelse(grepl(" ", req(input$newvar_name)),
-          sprintf('%s[,"%s"]', req(input$obj_name), req(input$newvar_name)),
-          sprintf("%s$%s", req(input$obj_name), req(input$newvar_name))
-        )
+        dest_var <- req(input$newvar_name)
+        if (make.names(dest_var) != dest_var) {
+          dest_var <- paste0('`', dest_var, '`')
+        }
+        dest_var <- sprintf("%s$%s", req(input$obj_name), dest_var)        
       }
       if (is.vector(robj()) || is.factor(robj())) {
         dest_var <- req(input$newvar_name)
@@ -400,14 +402,13 @@ iorder <- function(obj = NULL, var_name = NULL) {
       out <- paste(out, collapse = "\n")
       if (run_as_addin) {
         rstudioapi::insertText(text = out)
-      } else {
-        out <- paste0(
-          gettext("\n-------- Start recoding code --------\n\n", domain = "R-questionr"),
-          out,
-          gettext("\n--------- End recoding code ---------\n", domain = "R-questionr")
-        )
-        cat(out)
       }
+     out <- paste0(
+        gettext("\n-------- Start recoding code --------\n\n", domain = "R-questionr"),
+        out,
+        gettext("\n--------- End recoding code ---------\n", domain = "R-questionr")
+      )
+      cat(out)
       stopApp()
     })
 
